translate.storage.wordfast.WordfastDialect

Package translate :: Package storage :: Module wordfast :: Class WordfastDialect |
[hide private]
[frames] | no frames]

# Class WordfastDialect

source code

Describe the properties of a Wordfast generated TAB-delimited file.

Instance Methods | [hide private]
Inherited from `csv.Dialect`: `__init__` Inherited from `csv.Dialect` (private): `_validate`

Class Variables | [hide private]
| delimiter = `"\t"` hash(x)
| lineterminator = `"\r\n"` hash(x)
| quoting = `csv.QUOTE_MINIMAL` hash(x)
| doublequote = `False` hash(x)
| skipinitialspace = `False` hash(x)
| escapechar = `None` hash(x)
| quotechar = `'"'` hash(x)
Inherited from `csv.Dialect` (private): `_name`, `_valid`